@@ -2,8 +2,8 @@
 
 import traceback
 
-from inferex import __app_name__, cli
-from inferex.io.human import technical_support
+from inferex import __app_name__
+from inferex.cli import cli
 
 
 def main():
@@ -11,12 +11,14 @@ def main():
     and will be run when "inferex" is executed as a command from the CLI
     """
     try:
-        cli.app(prog_name=__app_name__)
+        # cli.app(prog_name=__app_name__)
+        cli(prog_name=__app_name__)
     except Exception as exc:  # pylint: disable=W0703
-        print(
-            "\nTraceback:\n"+ "\n".join(traceback.format_tb(exc.__traceback__)) +
+        print( # TODO: format traceback to show relevant lines
+            "\nTraceback:\n"+"\n".join(traceback.format_tb(exc.__traceback__)) +
             f"Unhandled exception - {exc}"
-            f"{technical_support()}"
+            "\n\nNeed assistance? \033[1mSpeak to an engineer!\033[0m "
+            "https://calendly.com/inferex\n\n"
         )
 
 
